nbxmpp.proxy_connectors.HTTPCONNECTConnector

Package nbxmpp :: Module proxy_connectors :: Class HTTPCONNECTConnector |
[hide private]
[frames] | no frames]

# Class HTTPCONNECTConnector

source code

Instance Methods | [hide private]
start_connecting(self) Connect to a proxy, supply login and password to it (if were specified while creating instance). Instruct proxy to make connection to the target server. | source code
_on_headers_sent(self, reply) | source code
Inherited from `ProxyConnector`: `__init__`, `connecting_over`

Class Methods | [hide private]
Inherited from `ProxyConnector`: `get_instance`

Method Details | [hide private]

### start_connecting(self) | source code
Connect to a proxy, supply login and password to it (if were specified while creating instance). Instruct proxy to make connection to the target server. Overrides: ProxyConnector.start_connecting

### _on_headers_sent(self, reply) | source code